@@ -7,7 +7,7 @@ from swift_cloud_py.entities.intersection.intersection import Intersection
 from swift_cloud_py.entities.intersection.traffic_light import TrafficLight
 from swift_cloud_py.entities.intersection.signalgroup import SignalGroup
 from swift_cloud_py.entities.control_output.fixed_time_schedule import FixedTimeSchedule, GreenYellowInterval
-from swift_cloud_py.entities.intersection.sg_relations import SyncStart, Offset, PreStart, Conflict
+from swift_cloud_py.entities.intersection.sg_relations import SyncStart, Offset, GreenyellowLead, Conflict
 from swift_cloud_py.validate_safety_restrictions.validate_other_sg_relations import find_other_sg_relation_matches, \
     get_shift_of_one_to_one_match, get_other_sg_relation_shift, validate_other_sg_relations
 
@@ -180,7 +180,7 @@ class TestGetOtherRelationShift(unittest.TestCase):
 
 
 class TestFTSOtherSGRelationValidation(unittest.TestCase):
-    """ Test validation of other  sg relations (synchronous starts, offsets, prestarts,...)"""
+    """ Test validation of other  sg relations (synchronous starts, offsets, greenyellow-leads,...)"""
 
     @staticmethod
     def get_default_signalgroup(name: str, min_greenyellow: float = 10.0, max_greenyellow: float = 80.0,
@@ -195,14 +195,14 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
     def get_default_intersection(additional_signalgroups: Optional[List[SignalGroup]] = None,
                                  sync_starts: List[SyncStart] = None,
                                  offsets: List[Offset] = None,
-                                 prestarts: List[PreStart] = None,
+                                 greenyellow_leads: List[GreenyellowLead] = None,
                                  ) -> Intersection:
         """
         Get a default intersection object with 2 conflicting signal groups "sg1" and "sg2"
         :param additional_signalgroups: signal groups to add to the intersection (besides signal group 'sg1' and 'sg2')
         :param sync_starts: SyncStarts that must be satisfied
         :param offsets: Coordinations that must be satisfied
-        :param prestarts: PreStarts that must be satisfied
+        :param greenyellow_leads: PreStarts that must be satisfied
         :return: the intersection object
         """
         if additional_signalgroups is None:
@@ -212,8 +212,8 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
             sync_starts = []
         if offsets is None:
             offsets = []
-        if prestarts is None:
-            prestarts = []
+        if greenyellow_leads is None:
+            greenyellow_leads = []
 
         signalgroup1 = TestFTSOtherSGRelationValidation.get_default_signalgroup(name="sg1")
         signalgroup2 = TestFTSOtherSGRelationValidation.get_default_signalgroup(name="sg2")
@@ -222,7 +222,7 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
 
         intersection = Intersection(signalgroups=[signalgroup1, signalgroup2] + additional_signalgroups,
                                     conflicts=[conflict], sync_starts=sync_starts, offsets=offsets,
-                                    prestarts=prestarts)
+                                    greenyellow_leads=greenyellow_leads)
 
         return intersection
 
@@ -339,15 +339,16 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
 
                     # THEN a SafetyViolation error should be raised
 
-    def test_correct_prestart(self) -> None:
+    def test_correct_greenyellow_lead(self) -> None:
         """
-        Test that validation of correct prestart passes.
+        Test that validation of correct greenyellow-lead passes.
         :return:
         """
         # GIVEN
-        min_prestart = 20
-        max_prestart = 30
-        prestart = PreStart(from_id="sg3", to_id="sg4", min_seconds=min_prestart, max_seconds=max_prestart)
+        min_greenyellow_lead = 20
+        max_greenyellow_lead = 30
+        greenyellow_lead = GreenyellowLead(from_id="sg3", to_id="sg4",
+                                           min_seconds=min_greenyellow_lead, max_seconds=max_greenyellow_lead)
         fts = FixedTimeSchedule(greenyellow_intervals=dict(
             sg1=[GreenYellowInterval(start_greenyellow=15, end_greenyellow=35)],
             sg2=[GreenYellowInterval(start_greenyellow=45, end_greenyellow=65)],
@@ -359,13 +360,13 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
         signalgroup3 = TestFTSOtherSGRelationValidation.get_default_signalgroup(name="sg3")
         signalgroup4 = TestFTSOtherSGRelationValidation.get_default_signalgroup(name="sg4")
         intersection = TestFTSOtherSGRelationValidation.get_default_intersection(
-            additional_signalgroups=[signalgroup3, signalgroup4], prestarts=[prestart])
+            additional_signalgroups=[signalgroup3, signalgroup4], greenyellow_leads=[greenyellow_lead])
 
-        for pre_start_time in [min_prestart, max_prestart]:
+        for pre_start_time in [min_greenyellow_lead, max_greenyellow_lead]:
             for interval_shift in range(2):
                 fts_copy = deepcopy(fts)
 
-                # adjust schedule to the specified prestart
+                # adjust schedule to the specified greenyellow_lead
                 for index, greenyellow_interval in enumerate(fts_copy.get_greenyellow_intervals(signalgroup4)):
                     greenyellow_start = (greenyellow_interval.start_greenyellow - pre_start_time) % fts_copy.period
                     greenyellow_end = (greenyellow_start + 20) % fts_copy.period
@@ -375,21 +376,22 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
                 fts_copy._greenyellow_intervals["sg4"] = fts_copy._greenyellow_intervals["sg4"][:interval_shift] + \
                     fts_copy._greenyellow_intervals["sg4"][interval_shift:]
 
-                with self.subTest(f"prestart={pre_start_time}, interval_shift={interval_shift}"):
+                with self.subTest(f"greenyellow_lead={pre_start_time}, interval_shift={interval_shift}"):
                     # WHEN validating
                     validate_other_sg_relations(intersection=intersection, fts=fts_copy)
 
                     # THEN no error should be raised
 
-    def test_incorrect_prestart(self) -> None:
+    def test_incorrect_greenyellow_lead(self) -> None:
         """
-        Test that validation of incorrect prestart raises SafetyViolation.
+        Test that validation of incorrect greenyellow-lead raises SafetyViolation.
         :return:
         """
         # GIVEN
-        min_prestart = 20
-        max_prestart = 30
-        prestart = PreStart(from_id="sg3", to_id="sg4", min_seconds=min_prestart, max_seconds=max_prestart)
+        min_greenyellow_lead = 20
+        max_greenyellow_lead = 30
+        greenyellow_lead = GreenyellowLead(from_id="sg3", to_id="sg4",
+                                           min_seconds=min_greenyellow_lead, max_seconds=max_greenyellow_lead)
         fts = FixedTimeSchedule(greenyellow_intervals=dict(
             sg1=[GreenYellowInterval(start_greenyellow=15, end_greenyellow=35)],
             sg2=[GreenYellowInterval(start_greenyellow=45, end_greenyellow=65)],
@@ -401,13 +403,13 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
         signalgroup3 = TestFTSOtherSGRelationValidation.get_default_signalgroup(name="sg3")
         signalgroup4 = TestFTSOtherSGRelationValidation.get_default_signalgroup(name="sg4")
         intersection = TestFTSOtherSGRelationValidation.get_default_intersection(
-            additional_signalgroups=[signalgroup3, signalgroup4], prestarts=[prestart])
+            additional_signalgroups=[signalgroup3, signalgroup4], greenyellow_leads=[greenyellow_lead])
 
-        for pre_start_time in [min_prestart - 1, max_prestart + 1]:
+        for pre_start_time in [min_greenyellow_lead - 1, max_greenyellow_lead + 1]:
             for interval_shift in range(2):
                 fts_copy = deepcopy(fts)
 
-                # adjust schedule to the specified prestart
+                # adjust schedule to the specified greenyellow-lead
                 for index, greenyellow_interval in enumerate(fts_copy.get_greenyellow_intervals(signalgroup4)):
                     greenyellow_start = (greenyellow_interval.start_greenyellow - pre_start_time) % fts_copy.period
                     greenyellow_end = (greenyellow_start + 20) % fts_copy.period
@@ -417,7 +419,7 @@ class TestFTSOtherSGRelationValidation(unittest.TestCase):
                 fts_copy._greenyellow_intervals["sg4"] = fts_copy._greenyellow_intervals["sg4"][:interval_shift] + \
                     fts_copy._greenyellow_intervals["sg4"][interval_shift:]
 
-                with self.subTest(f"prestart={pre_start_time}, interval_shift={interval_shift}"):
+                with self.subTest(f"greenyellow_lead={pre_start_time}, interval_shift={interval_shift}"):
                     with self.assertRaises(SafetyViolation):
                         # WHEN validating
                         validate_other_sg_relations(intersection=intersection, fts=fts_copy)
